@@ -53,7 +53,7 @@ public:
     {
         setItem(item);
     }
-    virtual ~ParsedRoute()
+    ~ParsedRoute() override
     {
         if (item) {
             item->deleteLater();
@@ -99,7 +99,7 @@ struct LRU {
     int totalCosts()
     {
         int ret = 0;
-        for (auto cost : qAsConst(costs)) {
+        for (auto cost : std::as_const(costs)) {
             ret += cost;
         }
         return ret;
@@ -171,7 +171,7 @@ class PreloadRouteGroup : public QObject
     PageRouterAttached *m_parent;
 
 public:
-    ~PreloadRouteGroup();
+    ~PreloadRouteGroup() override;
     void setRoute(QJSValue route)
     {
         m_route = route;
@@ -499,8 +499,13 @@ private:
     void placeInCache(ParsedRoute *route);
 
     static void appendRoute(QQmlListProperty<PageRoute> *list, PageRoute *);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     static int routeCount(QQmlListProperty<PageRoute> *list);
     static PageRoute *route(QQmlListProperty<PageRoute> *list, int);
+#else
+    static qsizetype routeCount(QQmlListProperty<PageRoute> *list);
+    static PageRoute *route(QQmlListProperty<PageRoute> *list, qsizetype);
+#endif
     static void clearRoutes(QQmlListProperty<PageRoute> *list);
 
     QVariant dataFor(QObject *object);
@@ -517,7 +522,7 @@ protected:
 
 public:
     PageRouter(QQuickItem *parent = nullptr);
-    ~PageRouter();
+    ~PageRouter() override;
 
     QQmlListProperty<PageRoute> routes();
 
